veloxml package
===============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   veloxml.base
   veloxml.core
   veloxml.kmeans
   veloxml.linear
   veloxml.pca
   veloxml.svm
   veloxml.tree

Module contents
---------------

.. automodule:: veloxml
   :members:
   :show-inheritance:
   :undoc-members:
